1.2
---

- Fixed a bug that would cause the login to fail when the login route was not at '/login'.

1.1
---

- Added an example app in demo/.
- Fixed compatibility with pyramid 1.3.
- Renamed the setting persona.audience to persona.audiences to match the PyBrowserID API.
- Added the "persona.verifier" setting to change the verifier.
- Added various settings to customize the login dialog.
- Compatibility with python 3.

1.0
---

-  Initial version
